@@ -78,6 +78,7 @@
       {"bareiss"         ,1, _BAREISS, _INT_SOLVER,T_NUMBER},
       {"base"         ,1,_BASE , _INT_MAPLECONVERSION ,T_NUMBER},
       {"begin",0,0,0,T_BLOC_BEGIN},
+      {"bipartite",0,    _GT_BIPARTITE, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"bisection_solver"         ,1, _BISECTION_SOLVER, _INT_SOLVER,T_NUMBER},
       {"blanc"         ,1, _WHITE, _INT_COLOR ,T_NUMBER},
       {"bleu"         ,1, _BLUE, _INT_COLOR ,T_NUMBER},
@@ -88,8 +89,9 @@
       {"cap_square_line"         ,1, _CAP_SQUARE_LINE, _INT_COLOR ,T_NUMBER},
       {"case",0,0,0,T_CASE},
       {"catch",0,0,0,T_CATCH},
-      {"complex"               ,0, _CPLX, _INT_TYPE, T_TYPE_ID},
+      // {"complex"               ,0, _CPLX, _INT_TYPE, T_TYPE_ID},
       {"confrac"         ,1,_CONFRAC , _INT_MAPLECONVERSION ,T_NUMBER},
+      {"connected",0,    _GT_CONNECTED, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"continue",0,0,0,T_CONTINUE},
       {"coords"         ,1, _COORDS, _INT_PLOT ,T_NUMBER},
       {"cross_point"         ,1, 0  , _INT_COLOR ,T_NUMBER},
@@ -98,6 +100,7 @@
       {"dashdot_line"         ,1, _DASHDOT_LINE, _INT_COLOR ,T_NUMBER},
       {"dashdotdot_line"         ,1, _DASHDOTDOT_LINE, _INT_COLOR ,T_NUMBER},
       {"default",1,0,0,T_DEFAULT},
+      {"directed",0,    _GT_DIRECTED, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"dnewton_solver"         ,1, _DNEWTON_SOLVER, _INT_SOLVER,T_NUMBER},
       {"dot_line"         ,1, _DOT_LINE, _INT_COLOR ,T_NUMBER},
       {"double"               ,0, _DOUBLE_, _INT_TYPE, T_TYPE_ID},
@@ -301,6 +304,11 @@
       {"newton_solver"         ,1, _NEWTON_SOLVER, _INT_SOLVER,T_NUMBER},
       {"newtonj_solver"         ,1, _NEWTONJ_SOLVER, _INT_SOLVER,T_NUMBER},
       {"next",0,0,0,T_CONTINUE},
+      {"nlp_initialpoint",0,    _NLP_INITIALPOINT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_iterationlimit",0,    _NLP_ITERATIONLIMIT, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_maximize",0,    _NLP_MAXIMIZE, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_nonnegative",0,    _NLP_NONNEGATIVE, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"nlp_precision",0,    _NLP_PRECISION, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"noir"         ,1, _BLACK, _INT_COLOR ,T_NUMBER},
       {"nonnegint"               ,0, _NONNEGINT, _INT_MAPLECONVERSION, T_TYPE_ID},
       {"nonposint"               ,0, _NONPOSINT, _INT_MAPLECONVERSION, T_TYPE_ID},
@@ -311,6 +319,7 @@
       {"of",0,0,0,T_OF},
       {"otherwise",0,0,0,T_DEFAULT},
       {"parfrac"         ,1,_PARFRAC , _INT_MAPLECONVERSION ,T_NUMBER},
+      {"planar",0,    _GT_PLANAR, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"plex"         ,1,_PLEX_ORDER , _INT_GROEBNER ,T_NUMBER},
       {"plus_point"         ,1, _POINT_PLUS , _INT_COLOR ,T_NUMBER},
       {"point_carre"         ,1, _POINT_CARRE  , _INT_COLOR ,T_NUMBER},
@@ -358,6 +367,7 @@
       {"set"         ,0,_SET__VECT , _INT_MAPLECONVERSION ,T_TYPE_ID},
       {"simpson"         ,1, _SIMPSON, _INT_SOLVER,T_NUMBER},
       {"solid_line"         ,1, 0, _INT_COLOR ,T_NUMBER},
+      {"spring",0,    _GT_SPRING, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"square_point"         ,1, _POINT_CARRE  , _INT_COLOR ,T_NUMBER},
       {"stack",0,0,0,T_STACK},
       {"star_point"         ,1, _POINT_ETOILE , _INT_COLOR ,T_NUMBER},
@@ -378,6 +388,7 @@
       {"trames"         ,1,_FRAMES , _INT_PLOT ,T_NUMBER},
       {"trapeze"         ,1, _TRAPEZE, _INT_SOLVER,T_NUMBER},
       {"trapezoid"         ,1, _TRAPEZE, _INT_SOLVER,T_NUMBER},
+      {"tree",0,    _GT_TREE, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"triangle_point"         ,1, _POINT_TRIANGLE , _INT_COLOR ,T_NUMBER},
       {"trig"         ,1,_TRIG , _INT_MAPLECONVERSION ,T_NUMBER},
       {"true",1,1,_INT_BOOLEAN,T_NUMBER},
@@ -393,6 +404,8 @@
       {"view"         ,1, _VIEW, _INT_PLOT ,T_NUMBER},
       {"vrai",1,1,_INT_BOOLEAN,T_NUMBER},
       {"vstep"         ,1, _VSTEP , _INT_PLOT ,T_NUMBER},
+      {"weighted",0,    _GT_WEIGHTED, _INT_MAPLECONVERSION,T_TYPE_ID},
+      {"weights",0,    _GT_WEIGHTS, _INT_MAPLECONVERSION,T_TYPE_ID},
       {"with_cocoa"         ,1,_WITH_COCOA , _INT_GROEBNER ,T_NUMBER},
       {"with_f5"         ,1,_WITH_F5 , _INT_GROEBNER ,T_NUMBER},
       {"xstep"         ,1, _XSTEP , _INT_PLOT ,T_NUMBER},
